/*
** 1998-10-15 -	Header for the size & position config module.
*/

extern const CfgModule *	cwn_describe(MainInfo *min);
